@@ -107,6 +107,7 @@ def send(action: str,
         - DrawGeometry
         - DisableDraw
         - BakePollinationModel
+        - SaveResults
     
     data: dict or List[dict]
         A ladybug geometry dictionary or a list of ladybug geometry dictionary.
@@ -173,7 +174,7 @@ if not _RELEASE:
     option = st.selectbox(
      "What command do you want to use?",
      ("BakeGeometry", "ClearGeometry", "DrawGeometry", 
-        "DisableDraw"))
+        "DisableDraw", "SaveResults"))
     
     command_active = send(
         action=option,
@@ -189,7 +190,7 @@ if not _RELEASE:
     st.write(data_to_pass)
 
     st.subheader("Pollination, Get Geometry Button")
-    geometry = get(key="secret-key-4")
+    geometry = get(key="secret-key-4", platform="sketchup")
     if geometry:
         st.write(json.loads(geometry))
 
