@@ -19,8 +19,10 @@ else:
 def send(data: Union[dict, List[dict]], 
     uniqueId: str, 
     defaultChecked: Optional[bool] = False,
+    isPollinationModel: Optional[bool] = False,
     options: Optional[dict] = {},
     label: Optional[str] = 'Draw Geometry',
+    delay: Optional[int] = 500, 
     key=None) -> str:
     """Create a new instance of "button.send".
 
@@ -32,6 +34,8 @@ def send(data: Union[dict, List[dict]],
         A text to display next to the checkbox.
     defaultChecked: bool
         Initial status of the checkbox.
+    isPollinationModel: bool
+        True if your data is a Pollination Model.
     uniqueId: str
         A key to recognize what geometries come from streamlit on Rhino. It becomes 
         a userString inside Rhino.
@@ -43,6 +47,9 @@ def send(data: Union[dict, List[dict]],
                 "layer": "My-Custom-Layer",
                 "units': "Meters"
             }
+    
+    delay: number
+        Set the time in milliseconds to keep as delay of the refresh.
     key: str or None
         An optional key that uniquely identifies this component. If this is
         None, and the component's arguments are changed, the component will
@@ -52,8 +59,10 @@ def send(data: Union[dict, List[dict]],
         data=data,
         label=label,
         defaultChecked=defaultChecked,
+        isPollinationModel=isPollinationModel,
         uniqueId=uniqueId,
         options=options,
+        delay=delay,
         key=key, 
         default="NAN")
 
